@@ -16,17 +16,14 @@ package org.codehaus.plexus.compiler.util.scan.mapping;
  * limitations under the License.
  */
 
-import org.codehaus.plexus.compiler.util.scan.InclusionScanException;
-
 import java.io.File;
 import java.util.Set;
 
+import org.codehaus.plexus.compiler.util.scan.InclusionScanException;
+
 /**
  * @author jdcasey
- * @version $Id$
  */
-public interface SourceMapping
-{
-    Set<File> getTargetFiles( File targetDir, String source )
-        throws InclusionScanException;
+public interface SourceMapping {
+    Set<File> getTargetFiles(File targetDir, String source) throws InclusionScanException;
 }
