@@ -20,26 +20,21 @@ import java.util.Collections;
 import java.util.HashSet;
 import java.util.Set;
 
+import org.junit.jupiter.api.BeforeEach;
 
 /**
  * Test for
  *
  * @author <a href="mailto:carlos@apache.org">Carlos Sanchez</a>
  */
-public class SimpleSourceInclusionScannerTest
-    extends AbstractSourceInclusionScannerTest
-{
+public class SimpleSourceInclusionScannerTest extends AbstractSourceInclusionScannerTest {
 
     private Set<String> includes, excludes;
 
-    protected void setUp()
-        throws Exception
-    {
-        super.setUp();
-
-        includes = Collections.singleton( "*.java" );
-        excludes = new HashSet<String>();
-        scanner = new SimpleSourceInclusionScanner( includes, excludes );
+    @BeforeEach
+    public void setUp() throws Exception {
+        includes = Collections.singleton("*.java");
+        excludes = new HashSet<>();
+        scanner = new SimpleSourceInclusionScanner(includes, excludes);
     }
-
 }
