@@ -23,37 +23,30 @@ package org.codehaus.plexus.compiler.manager;
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-
-import org.codehaus.plexus.compiler.Compiler;
-import org.codehaus.plexus.logging.AbstractLogEnabled;
+import javax.inject.Inject;
+import javax.inject.Named;
 
 import java.util.Map;
 
+import org.codehaus.plexus.compiler.Compiler;
+
 /**
  * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
- * @plexus.component
  */
-public class DefaultCompilerManager
-    extends AbstractLogEnabled
-    implements CompilerManager
-{
-    /**
-     * @plexus.requirement role="org.codehaus.plexus.compiler.Compiler"
-     */
+@Named
+public class DefaultCompilerManager implements CompilerManager {
+    @Inject
     private Map<String, Compiler> compilers;
 
     // ----------------------------------------------------------------------
     // CompilerManager Implementation
     // ----------------------------------------------------------------------
 
-    public Compiler getCompiler( String compilerId )
-        throws NoSuchCompilerException
-    {
-        Compiler compiler = compilers.get( compilerId );
+    public Compiler getCompiler(String compilerId) throws NoSuchCompilerException {
+        Compiler compiler = compilers.get(compilerId);
 
-        if ( compiler == null )
-        {
-            throw new NoSuchCompilerException( compilerId );
+        if (compiler == null) {
+            throw new NoSuchCompilerException(compilerId);
         }
 
         return compiler;
