@@ -23,18 +23,13 @@ package org.codehaus.plexus.compiler.eclipse;
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-
 import org.codehaus.plexus.compiler.AbstractCompilerTckTest;
 
 /**
  * @author <a href="mailto:trygvis@inamo.no">Trygve Laugst&oslash;l</a>
- * @version $Id$
  */
-public class EclipseCompilerTckTest
-    extends AbstractCompilerTckTest
-{
-    public EclipseCompilerTckTest()
-    {
-        super( "eclipse" );
+public class EclipseCompilerTckTest extends AbstractCompilerTckTest {
+    public EclipseCompilerTckTest() {
+        this.roleHint = "eclipse";
     }
 }
