@@ -21,25 +21,16 @@ package org.codehaus.plexus.compiler.javac;
 /**
  * @author Olivier Lamy
  */
-public class JavaxToolsCompilerTest
-    extends AbstractJavacCompilerTest
-{
+public class JavaxToolsCompilerTest extends AbstractJavacCompilerTest {
     // no op default is to javax.tools if available
 
-    protected int expectedWarnings()
-    {
-        if (getJavaVersion().contains("1.8")){
-            // lots of new warnings about obsoletions for future releases
-            return 30;
-        }
-        else if ( "1.6".compareTo( getJavaVersion() ) < 0 )
-        {
-            // with 1.7 some warning with bootstrap class path not set in conjunction with -source 1.3
-            return 9;
-        }
-        else
-        {
-            return 2;
+    @Override
+    protected int expectedWarnings() {
+        String javaVersion = getJavaVersion();
+        if (javaVersion.contains("21")) {
+            return 8;
+        } else {
+            return super.expectedWarnings();
         }
     }
 }
